@@ -13,6 +13,7 @@ import csv
 import os
 from typing import BinaryIO, Optional, TextIO, Tuple
 
+from deprecated.sphinx import deprecated
 import librosa
 import numpy as np
 
@@ -32,6 +33,12 @@ BIBTEX = """@inproceedings{mauch2009beatles,
     series = {ISMIR}
 }"""
 
+INDEXES = {
+    "default": "1.2",
+    "test": "1.2",
+    "1.2": core.Index(filename="beatles_index_1.2.json"),
+}
+
 REMOTES = {
     "annotations": download_utils.RemoteFileMetadata(
         filename="The Beatles Annotations.tar.gz",
@@ -185,7 +192,10 @@ def load_beats(fhandle: TextIO) -> annotations.BeatData:
     beat_positions = _fix_newpoint(np.array(beat_positions))  # type: ignore
     # After fixing New Point labels convert positions to int
     beat_data = annotations.BeatData(
-        np.array(beat_times), np.array([int(b) for b in beat_positions])
+        np.array(beat_times),
+        "s",
+        np.array([int(b) for b in beat_positions]),
+        "bar_index",
     )
 
     return beat_data
@@ -211,7 +221,9 @@ def load_chords(fhandle: TextIO) -> annotations.ChordData:
         end_times.append(float(line[1]))
         chords.append(line[2])
 
-    return annotations.ChordData(np.array([start_times, end_times]).T, chords)
+    return annotations.ChordData(
+        np.array([start_times, end_times]).T, "s", chords, "harte"
+    )
 
 
 @io.coerce_to_string_io
@@ -233,7 +245,9 @@ def load_key(fhandle: TextIO) -> annotations.KeyData:
             end_times.append(float(line[1]))
             keys.append(line[3])
 
-    return annotations.KeyData(np.array([start_times, end_times]).T, keys)
+    return annotations.KeyData(
+        np.array([start_times, end_times]).T, "s", keys, "key_mode"
+    )
 
 
 @io.coerce_to_string_io
@@ -253,7 +267,9 @@ def load_sections(fhandle: TextIO) -> annotations.SectionData:
         end_times.append(float(line[1]))
         sections.append(line[3])
 
-    return annotations.SectionData(np.array([start_times, end_times]).T, sections)
+    return annotations.SectionData(
+        np.array([start_times, end_times]).T, "s", sections, "open"
+    )
 
 
 def _fix_newpoint(beat_positions: np.ndarray) -> np.ndarray:
@@ -281,29 +297,43 @@ class Dataset(core.Dataset):
     The beatles dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="beatles",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             download_info=DOWNLOAD_INFO,
             license_info=LICENSE_INFO,
         )
 
-    @core.copy_docs(load_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.beatles.load_audio",
+        version="0.3.4",
+    )
     def load_audio(self, *args, **kwargs):
         return load_audio(*args, **kwargs)
 
-    @core.copy_docs(load_beats)
+    @deprecated(
+        reason="Use mirdata.datasets.beatles.load_beats",
+        version="0.3.4",
+    )
     def load_beats(self, *args, **kwargs):
         return load_beats(*args, **kwargs)
 
-    @core.copy_docs(load_chords)
+    @deprecated(
+        reason="Use mirdata.datasets.beatles.load_chords",
+        version="0.3.4",
+    )
     def load_chords(self, *args, **kwargs):
         return load_chords(*args, **kwargs)
 
-    @core.copy_docs(load_sections)
+    @deprecated(
+        reason="Use mirdata.datasets.beatles.load_sections",
+        version="0.3.4",
+    )
     def load_sections(self, *args, **kwargs):
         return load_sections(*args, **kwargs)
