@@ -18,18 +18,15 @@
 
 import csv
 import json
-import logging
 import os
-from typing import BinaryIO, cast, Optional, TextIO, Tuple
+from typing import BinaryIO, Optional, TextIO, Tuple
 
+from deprecated.sphinx import deprecated
 import librosa
 import numpy as np
+from smart_open import open
 
-from mirdata import download_utils
-from mirdata import jams_utils
-from mirdata import core
-from mirdata import annotations
-from mirdata import io
+from mirdata import annotations, core, io, jams_utils
 
 BIBTEX = """@inproceedings{bittner2014medleydb,
     Author = {Bittner, Rachel M and Salamon, Justin and Tierney, Mike and Mauch, Matthias and Cannam, Chris and Bello, Juan P},
@@ -38,6 +35,12 @@ BIBTEX = """@inproceedings{bittner2014medleydb,
     Title = {Medley{DB}: A Multitrack Dataset for Annotation-Intensive {MIR} Research},
     Year = {2014}
 }"""
+INDEXES = {
+    "default": "5.0",
+    "test": "5.0",
+    "5.0": core.Index(filename="medleydb_melody_index_5.0.json"),
+}
+
 DOWNLOAD_INFO = """
     To download this dataset, visit:
     https://zenodo.org/record/2628782#.XKZdABNKh24
@@ -194,15 +197,18 @@ def load_melody(fhandle: TextIO) -> annotations.F0Data:
     """
     times = []
     freqs = []
+    voicing = []
     reader = csv.reader(fhandle, delimiter=",")
     for line in reader:
         times.append(float(line[0]))
-        freqs.append(float(line[1]))
+        freq_val = float(line[1])
+        freqs.append(freq_val)
+        voicing.append(float(freq_val > 0))
 
     times = np.array(times)  # type: ignore
     freqs = np.array(freqs)  # type: ignore
-    confidence = (cast(np.ndarray, freqs) > 0).astype(float)
-    return annotations.F0Data(times, freqs, confidence)
+    voicing = np.array(voicing)  # type: ignore
+    return annotations.F0Data(times, "s", freqs, "hz", voicing, "binary")
 
 
 @io.coerce_to_string_io
@@ -225,11 +231,13 @@ def load_melody3(fhandle: TextIO) -> annotations.MultiF0Data:
     reader = csv.reader(fhandle, delimiter=",")
     for line in reader:
         times.append(float(line[0]))
-        freqs_list.append([float(v) for v in line[1:]])
-        conf_list.append([float(float(v) > 0) for v in line[1:]])
+        freqs_list.append([float(v) for v in line[1:] if float(v) != 0])
+        conf_list.append([1.0 for v in line[1:] if float(v) != 0])
 
     times = np.array(times)  # type: ignore
-    melody_data = annotations.MultiF0Data(times, freqs_list, conf_list)
+    melody_data = annotations.MultiF0Data(
+        times, "s", freqs_list, "hz", conf_list, "binary"
+    )
     return melody_data
 
 
@@ -239,12 +247,14 @@ class Dataset(core.Dataset):
     The medleydb_melody dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="medleydb_melody",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             download_info=DOWNLOAD_INFO,
             license_info=LICENSE_INFO,
         )
@@ -253,22 +263,31 @@ class Dataset(core.Dataset):
     def _metadata(self):
         metadata_path = os.path.join(self.data_home, "medleydb_melody_metadata.json")
 
-        if not os.path.exists(metadata_path):
+        try:
+            with open(metadata_path, "r") as fhandle:
+                metadata = json.load(fhandle)
+        except FileNotFoundError:
             raise FileNotFoundError("Metadata not found. Did you run .download()?")
 
-        with open(metadata_path, "r") as fhandle:
-            metadata = json.load(fhandle)
-
         return metadata
 
-    @core.copy_docs(load_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.medleydb_melody.load_audio",
+        version="0.3.4",
+    )
     def load_audio(self, *args, **kwargs):
         return load_audio(*args, **kwargs)
 
-    @core.copy_docs(load_melody)
+    @deprecated(
+        reason="Use mirdata.datasets.medleydb_melody.load_melody",
+        version="0.3.4",
+    )
     def load_melody(self, *args, **kwargs):
         return load_melody(*args, **kwargs)
 
-    @core.copy_docs(load_melody3)
+    @deprecated(
+        reason="Use mirdata.datasets.medleydb_melody.load_melody3",
+        version="0.3.4",
+    )
     def load_melody3(self, *args, **kwargs):
         return load_melody3(*args, **kwargs)
