@@ -1,6 +1,7 @@
 """Utilities for downloading from the web.
 """
 
+import chardet
 import glob
 import logging
 import os
@@ -8,9 +9,9 @@ import shutil
 import tarfile
 import urllib
 import zipfile
-import chardet
 
 from tqdm import tqdm
+from smart_open import open, parse_uri
 
 from mirdata.validate import md5
 
@@ -43,6 +44,7 @@ class RemoteFileMetadata(object):
 def downloader(
     save_dir,
     remotes=None,
+    index=None,
     partial_download=None,
     info_message=None,
     force_overwrite=False,
@@ -56,9 +58,12 @@ def downloader(
         remotes (dict or None):
             A dictionary of RemoteFileMetadata tuples of data in zip format.
             If None, there is no data to download
+        index (core.Index):
+            A mirdata Index class, which may contain a remote index to be downloaded
+            or a subset of remotes to download by default.
         partial_download (list or None):
             A list of keys to partially download the remote objects of the download dict.
-            If None, all data is downloaded
+            If None, all data specified by the index is downloaded
         info_message (str or None):
             A string of info to log when this function is called.
             If None, no string is logged.
@@ -71,14 +76,28 @@ def downloader(
     if not os.path.exists(save_dir):
         os.makedirs(save_dir)
 
+    if not index:
+        raise ValueError("Index must be specified.")
+
     if cleanup:
         logging.warning(
             "Zip and tar files will be deleted after they are uncompressed. "
-            + "If you download this dataset again, it will overwrite existing files, even if force_overwrite=False"
+            + "If you download this dataset again, it will overwrite existing files, even if"
+            " force_overwrite=False"
         )
 
-    if remotes is not None:
-        if partial_download is not None:
+    if index.remote:
+        # add index to remotes
+        if not remotes:
+            remotes = {}
+        remotes["index"] = index.remote
+
+    # if partial download is specified, use it. Otherwise, use the
+    # partial download specified by the index.
+    partial_download = partial_download if partial_download else index.partial_download
+
+    if remotes:
+        if partial_download:
             # check the keys in partial_download are in the download dict
             if not isinstance(partial_download, list) or any(
                 [k not in remotes for k in partial_download]
@@ -118,9 +137,10 @@ def downloader(
 
                     if not os.path.exists(source_dir):
                         logging.info(
-                            "Data not downloaded, because it probably already exists on your computer. "
-                            + "Run .validate() to check, or rerun with force_overwrite=True to delete any "
-                            + "existing files and download from scratch"
+                            "Data not downloaded, because it probably already exists on your"
+                            " computer. "
+                            + "Run .validate() to check, or rerun with force_overwrite=True to"
+                            " delete any " + "existing files and download from scratch"
                         )
                         return
 
@@ -161,6 +181,14 @@ def download_from_remote(remote, save_dir, force_overwrite):
         str: Full path of the created file.
 
     """
+    file_uri = parse_uri(save_dir)
+    if file_uri.scheme != "file":
+        raise NotImplementedError(
+            "mirdata only supports downloading to a local filesystem. "
+            "To use mirdata with a remote filesystem, download to a local filesytem, "
+            "and transfer the data to your remote filesystem, setting data_home appropriately."
+        )
+
     if remote.destination_dir is None:
         download_dir = save_dir
     else:
@@ -248,6 +276,7 @@ def extractall_unicode(zfile, out_dir):
 
     for m in zfile.infolist():
         data = zfile.read(m)  # extract zipped data into memory
+
         filename = m.filename
 
         # if block to deal with irmas and good-sounds archives
