@@ -5,6 +5,8 @@ import logging
 import os
 import tqdm
 
+from smart_open import open
+
 
 def md5(file_path):
     """Get md5 hash of a file.
@@ -17,7 +19,7 @@ def md5(file_path):
 
     """
     hash_md5 = hashlib.md5()
-    with open(file_path, "rb") as fhandle:
+    with open(file_path, "rb", compression="disable") as fhandle:
         for chunk in iter(lambda: fhandle.read(4096), b""):
             hash_md5.update(chunk)
     return hash_md5.hexdigest()
@@ -48,7 +50,10 @@ def validate(local_path, checksum):
 
     """
     # validate that the file exists on disk
-    if not os.path.exists(local_path):
+    try:
+        with open(local_path):
+            pass
+    except IOError:
         return False, False
 
     # validate that the checksum matches
@@ -76,12 +81,12 @@ def validate_files(file_dict, data_home, verbose):
     missing = {}
     invalid = {}
     for file_id, file in tqdm.tqdm(file_dict.items(), disable=not verbose):
-        # multitrack case
-        if file_id is "tracks":
-            continue
-        # tracks
-        else:
-            for tracks in file.keys():
+        for tracks in file.keys():
+            # multitrack case
+            if tracks == "tracks":
+                continue
+            # tracks
+            else:
                 filepath = file[tracks][0]
                 checksum = file[tracks][1]
                 if filepath is not None:
