@@ -4,7 +4,7 @@ import shutil
 import zipfile
 import re
 
-from mirdata import download_utils
+from mirdata import download_utils, core
 
 import pytest
 
@@ -42,52 +42,59 @@ def test_downloader(mocker, mock_path):
     )
 
     zip_remote = download_utils.RemoteFileMetadata(
-        filename="remote.zip", url="a", checksum=("1234")
+        filename="remote.zip", url="a", checksum="1234"
     )
     tar_remote = download_utils.RemoteFileMetadata(
-        filename="remote.tar.gz", url="a", checksum=("1234")
+        filename="remote.tar.gz", url="a", checksum="1234"
     )
 
     file_remote = download_utils.RemoteFileMetadata(
-        filename="remote.txt", url="a", checksum=("1234")
+        filename="remote.txt", url="a", checksum="1234"
     )
+    index = core.Index("asdf.json")
 
     # Zip only
-    download_utils.downloader("a", remotes={"b": zip_remote})
+    download_utils.downloader("a", index=index, remotes={"b": zip_remote})
     mock_zip.assert_called_once_with(zip_remote, "a", False, False)
     mocker.resetall()
 
     # tar only
-    download_utils.downloader("a", remotes={"b": tar_remote})
+    download_utils.downloader("a", index=index, remotes={"b": tar_remote})
     mock_tar.assert_called_once_with(tar_remote, "a", False, False)
     mocker.resetall()
 
     # file only
-    download_utils.downloader("a", remotes={"b": file_remote})
+    download_utils.downloader("a", index=index, remotes={"b": file_remote})
     mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
     mocker.resetall()
 
     # zip and tar
-    download_utils.downloader("a", remotes={"b": zip_remote, "c": tar_remote})
+    download_utils.downloader(
+        "a", index=index, remotes={"b": zip_remote, "c": tar_remote}
+    )
     mock_zip.assert_called_once_with(zip_remote, "a", False, False)
     mock_tar.assert_called_once_with(tar_remote, "a", False, False)
     mocker.resetall()
 
     # zip and file
-    download_utils.downloader("a", remotes={"b": zip_remote, "c": file_remote})
+    download_utils.downloader(
+        "a", index=index, remotes={"b": zip_remote, "c": file_remote}
+    )
     mock_zip.assert_called_once_with(zip_remote, "a", False, False)
     mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
     mocker.resetall()
 
     # tar and file
-    download_utils.downloader("a", remotes={"b": tar_remote, "c": file_remote})
+    download_utils.downloader(
+        "a", index=index, remotes={"b": tar_remote, "c": file_remote}
+    )
     mock_tar.assert_called_once_with(tar_remote, "a", False, False)
     mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
     mocker.resetall()
 
     # zip and tar and file
     download_utils.downloader(
-        "a", remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
+        "a", index=index, remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
     )
     mock_zip.assert_called_once_with(zip_remote, "a", False, False)
     mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
@@ -97,6 +104,7 @@ def test_downloader(mocker, mock_path):
     # test partial download
     download_utils.downloader(
         "a",
+        index=index,
         remotes={"b": zip_remote, "c": tar_remote, "d": file_remote},
         partial_download=["b", "d"],
     )
@@ -108,6 +116,7 @@ def test_downloader(mocker, mock_path):
     with pytest.raises(ValueError):
         download_utils.downloader(
             "a",
+            index=index,
             remotes={"b": zip_remote, "c": tar_remote, "d": file_remote},
             partial_download="b",
         )
@@ -115,147 +124,230 @@ def test_downloader(mocker, mock_path):
     with pytest.raises(ValueError):
         download_utils.downloader(
             "a",
+            index=index,
             remotes={"b": zip_remote, "c": tar_remote, "d": file_remote},
             partial_download=["d", "e"],
         )
 
     # test info message
-    download_utils.downloader("a", info_message="I am a message!")
+    download_utils.downloader("a", index=index, info_message="I am a message!")
     mocker.resetall()
 
     # test download twice - defaults
     download_utils.downloader(
-        "a", remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
+        "a", index=index, remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
     )
     download_utils.downloader(
-        "a", remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
+        "a", index=index, remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
     )
 
     # test download twice - cleanup=True
     download_utils.downloader(
-        "a", remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}, cleanup=True
+        "a",
+        index=index,
+        remotes={"b": zip_remote, "c": tar_remote, "d": file_remote},
+        cleanup=True,
     )
     download_utils.downloader(
-        "a", remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
+        "a", index=index, remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
     )
 
 
+def test_download_index_cases(mocker, mock_path):
+    mock_zip = mocker.patch.object(download_utils, "download_zip_file")
+    mock_download_from_remote = mocker.patch.object(
+        download_utils, "download_from_remote"
+    )
+
+    zip_remote = download_utils.RemoteFileMetadata(
+        filename="remote.zip", url="a", checksum="1234"
+    )
+    file_remote = download_utils.RemoteFileMetadata(
+        filename="remote.txt", url="a", checksum="1234"
+    )
+    index = core.Index("asdf.json")
+    index_partial = core.Index("asdf.json", partial_download=["b"])
+    remote_index = core.Index("asdf.json", url="b", checksum="4567")
+
+    # no remotes, no remote index
+    download_utils.downloader(
+        "a",
+        index=index,
+        remotes=None,
+        partial_download=None,
+    )
+    mock_zip.assert_not_called()
+    mock_download_from_remote.assert_not_called()
+    mocker.resetall()
+
+    # remotes, partial download index
+    download_utils.downloader(
+        "a",
+        index=index_partial,
+        remotes={"b": zip_remote, "d": file_remote},
+        partial_download=None,
+    )
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
+    mock_download_from_remote.assert_not_called()
+    mocker.resetall()
+
+    # remotes, partial download index overwrite
+    download_utils.downloader(
+        "a",
+        index=index_partial,
+        remotes={"b": zip_remote, "d": file_remote},
+        partial_download=["d"],
+    )
+    mock_zip.assert_not_called()
+    mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
+    mocker.resetall()
+
+    # no remotes, remote index
+    download_utils.downloader(
+        "a",
+        index=remote_index,
+        remotes=None,
+        partial_download=None,
+    )
+    mock_zip.assert_not_called()
+    mock_download_from_remote.assert_called_once_with(remote_index.remote, "a", False)
+    mocker.resetall()
+
+    # remotes, remote index
+    download_utils.downloader(
+        "a",
+        index=remote_index,
+        remotes={"b": zip_remote},
+        partial_download=None,
+    )
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
+    mock_download_from_remote.assert_called_once_with(remote_index.remote, "a", False)
+    mocker.resetall()
+
+
 def _clean(fpath):
     if os.path.exists(fpath):
         shutil.rmtree(fpath)
 
 
 def test_downloader_with_server_file(httpserver):
-
+    index = core.Index("asdf.json")
     httpserver.serve_content(open("tests/resources/remote.wav").read())
 
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.wav",
         url=httpserver.url,
-        checksum=("3f77d0d69dc41b3696f074ad6bf2852f"),
+        checksum="3f77d0d69dc41b3696f074ad6bf2852f",
     )
 
     save_dir = "tests/resources/tmp_download_test"
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
     # test downloading twice
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE}, cleanup=True)
+    download_utils.downloader(
+        save_dir, index=index, remotes={"b": TEST_REMOTE}, cleanup=True
+    )
     # test downloading twice
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
     # test downloading twice
     download_utils.downloader(
-        save_dir, remotes={"b": TEST_REMOTE}, force_overwrite=True
+        save_dir, index=index, remotes={"b": TEST_REMOTE}, force_overwrite=True
     )
 
     _clean(save_dir)
 
 
 def test_downloader_with_server_zip(httpserver):
-
+    index = core.Index("asdf.json")
     httpserver.serve_content(open("tests/resources/remote.zip", "rb").read())
 
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.zip",
         url=httpserver.url,
-        checksum=("7a31ccfa28bfa3fb112d16c96e9d9a89"),
+        checksum="7a31ccfa28bfa3fb112d16c96e9d9a89",
     )
 
     save_dir = "tests/resources/_tmp_test_download_utils"
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
     # test downloading twice
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE}, cleanup=True)
+    download_utils.downloader(
+        save_dir, index=index, remotes={"b": TEST_REMOTE}, cleanup=True
+    )
     # test downloading twice
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
     # test downloading twice
     download_utils.downloader(
-        save_dir, remotes={"b": TEST_REMOTE}, force_overwrite=True
+        save_dir, index=index, remotes={"b": TEST_REMOTE}, force_overwrite=True
     )
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE}, cleanup=True)
+    download_utils.downloader(
+        save_dir, index=index, remotes={"b": TEST_REMOTE}, cleanup=True
+    )
     # test downloading twice
     download_utils.downloader(
-        save_dir, remotes={"b": TEST_REMOTE}, force_overwrite=True
+        save_dir, index=index, remotes={"b": TEST_REMOTE}, force_overwrite=True
     )
 
     _clean(save_dir)
 
 
 def test_downloader_with_server_tar(httpserver):
-
+    index = core.Index("asdf.json")
     httpserver.serve_content(open("tests/resources/remote.tar.gz", "rb").read())
 
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.tar.gz",
         url=httpserver.url,
-        checksum=("9042f5eebdcd0b94aa7a3c9bf12dc51d"),
+        checksum="9042f5eebdcd0b94aa7a3c9bf12dc51d",
     )
 
     save_dir = "tests/resources/_tmp_test_download_utils"
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
     # test downloading twice
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE}, cleanup=True)
+    download_utils.downloader(
+        save_dir, index=index, remotes={"b": TEST_REMOTE}, cleanup=True
+    )
     # test downloading twice
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
 
     _clean(save_dir)
-    download_utils.downloader(save_dir, remotes={"b": TEST_REMOTE})
+    download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
     # test downloading twice
     download_utils.downloader(
-        save_dir, remotes={"b": TEST_REMOTE}, force_overwrite=True
+        save_dir, index=index, remotes={"b": TEST_REMOTE}, force_overwrite=True
     )
 
     _clean(save_dir)
 
 
 def test_download_from_remote(httpserver, tmpdir):
-
     httpserver.serve_content(open("tests/resources/remote.wav").read())
 
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.wav",
         url=httpserver.url,
-        checksum=("3f77d0d69dc41b3696f074ad6bf2852f"),
+        checksum="3f77d0d69dc41b3696f074ad6bf2852f",
     )
 
     download_path = download_utils.download_from_remote(TEST_REMOTE, str(tmpdir), False)
@@ -267,7 +359,7 @@ def test_download_from_remote_destdir(httpserver, tmpdir):
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.wav",
         url=httpserver.url,
-        checksum=("3f77d0d69dc41b3696f074ad6bf2852f"),
+        checksum="3f77d0d69dc41b3696f074ad6bf2852f",
         destination_dir="subfolder",
     )
 
@@ -282,13 +374,26 @@ def test_download_from_remote_raises_IOError(httpserver, tmpdir):
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.wav",
         url=httpserver.url,
-        checksum=("1234"),
+        checksum="1234",
     )
 
     with pytest.raises(IOError):
         download_utils.download_from_remote(TEST_REMOTE, str(tmpdir), False)
 
 
+def test_download_from_remote_raises_NotImplementedError(httpserver, tmpdir):
+    httpserver.serve_content("File not found!", 404)
+
+    TEST_REMOTE = download_utils.RemoteFileMetadata(
+        filename="remote.wav",
+        url=httpserver.url,
+        checksum="1234",
+    )
+
+    with pytest.raises(NotImplementedError):
+        download_utils.download_from_remote(TEST_REMOTE, "gs://asdf/asdf/asdf", False)
+
+
 def test_unzip():
     download_utils.unzip("tests/resources/file.zip", cleanup=False)
     expected_file_location = os.path.join("tests", "resources", "file.txt")
