@@ -19,28 +19,62 @@ def get_jam_data(jam, namespace, annot_numb):
 
 
 def test_beats():
-    beat_data_1 = [(annotations.BeatData(np.array([0.2, 0.3]), np.array([1, 2])), None)]
+    beat_data_1 = [
+        (
+            annotations.BeatData(
+                np.array([0.2, 0.3]), "s", np.array([1, 2]), "bar_index"
+            ),
+            None,
+        )
+    ]
     beat_data_2 = [
-        (annotations.BeatData(np.array([0.5, 0.7]), np.array([2, 3])), "beats_2")
+        (
+            annotations.BeatData(
+                np.array([0.5, 0.7]), "s", np.array([2, 3]), "bar_index"
+            ),
+            "beats_2",
+        )
     ]
     beat_data_3 = [
-        (annotations.BeatData(np.array([0.0, 0.3]), np.array([1, 2])), "beats_1"),
-        (annotations.BeatData(np.array([0.5, 0.8]), np.array([4, 3])), "beats_2"),
+        (
+            annotations.BeatData(
+                np.array([0.0, 0.3]), "s", np.array([1, 2]), "bar_index"
+            ),
+            "beats_1",
+        ),
+        (
+            annotations.BeatData(
+                np.array([0.5, 0.8]), "s", np.array([4, 3]), "bar_index"
+            ),
+            "beats_2",
+        ),
     ]
     beat_data_4 = (
-        annotations.BeatData(np.array([0.0, 0.3]), np.array([1, 2])),
+        annotations.BeatData(np.array([0.0, 0.3]), "s", np.array([1, 2]), "bar_index"),
         "beats_1",
     )
     beat_data_5 = [
-        (annotations.BeatData(np.array([0.0, 0.3]), np.array([1, 2])), "beats_1"),
-        [annotations.BeatData(np.array([0.5, 0.8]), np.array([4, 3])), "beats_2"],
+        (
+            annotations.BeatData(
+                np.array([0.0, 0.3]), "s", np.array([1, 2]), "bar_index"
+            ),
+            "beats_1",
+        ),
+        [
+            annotations.BeatData(
+                np.array([0.5, 0.8]), "s", np.array([4, 3]), "bar_index"
+            ),
+            "beats_2",
+        ],
     ]
     beat_data_6 = [(None, None)]
     beat_data_7 = [
         (
             annotations.EventData(
                 np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                "s",
                 ["event A", "event B"],
+                "open",
             ),
             None,
         )
@@ -92,7 +126,9 @@ def test_chords():
         (
             annotations.ChordData(
                 np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 ["A", "A", "E"],
+                "harte",
             ),
             None,
         )
@@ -101,7 +137,9 @@ def test_chords():
         (
             annotations.ChordData(
                 np.array([[0.0, 0.8, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 ["A", "B", "C"],
+                "harte",
             ),
             "chords_2",
         )
@@ -110,21 +148,28 @@ def test_chords():
         (
             annotations.ChordData(
                 np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 ["A", "A", "E"],
+                "harte",
             ),
             "chords_1",
         ),
         (
             annotations.ChordData(
                 np.array([[0.0, 0.7, 1.0], [0.7, 1.0, 1.5]]).T,
+                "s",
                 ["A", "B", "C"],
+                "harte",
             ),
             "chords_2",
         ),
     ]
     chord_data_4 = (
         annotations.ChordData(
-            np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T, ["A", "A", "E"]
+            np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T,
+            "s",
+            ["A", "A", "E"],
+            "harte",
         ),
         None,
     )
@@ -132,14 +177,18 @@ def test_chords():
         [
             annotations.ChordData(
                 np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 ["A", "A", "E"],
+                "harte",
             ),
             None,
         ],
         (
             annotations.ChordData(
                 np.array([[0.0, 0.8, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 ["A", "B", "C"],
+                "harte",
             ),
             "chords_2",
         ),
@@ -149,7 +198,9 @@ def test_chords():
         (
             annotations.EventData(
                 np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                "s",
                 ["event A", "event B"],
+                "open",
             ),
             None,
         )
@@ -201,8 +252,11 @@ def test_notes():
         (
             annotations.NoteData(
                 np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 np.array([1108.731, 1108.731, 1108.731]),
+                "hz",
                 np.array([1.0, 1.0, 1.0]),
+                "binary",
             ),
             None,
         )
@@ -211,8 +265,11 @@ def test_notes():
         (
             annotations.NoteData(
                 np.array([[0.0, 0.8, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 np.array([1108.731, 1108.731, 1108.731]),
+                "hz",
                 np.array([1.0, 1.0, 1.0]),
+                "binary",
             ),
             "notes_2",
         )
@@ -221,16 +278,22 @@ def test_notes():
         (
             annotations.NoteData(
                 np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 np.array([1108.731, 1108.731, 1108.731]),
+                "hz",
                 np.array([1.0, 1.0, 1.0]),
+                "binary",
             ),
             "notes_1",
         ),
         (
             annotations.NoteData(
                 np.array([[0.0, 0.7, 1.0], [0.7, 1.0, 1.5]]).T,
+                "s",
                 np.array([1108.731, 1108.731, 1108.731]),
+                "hz",
                 np.array([1.0, 1.0, 1.0]),
+                "binary",
             ),
             "notes_2",
         ),
@@ -238,8 +301,11 @@ def test_notes():
     note_data_4 = (
         annotations.NoteData(
             np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T,
+            "s",
             np.array([1108.731, 1108.731, 1108.731]),
+            "hz",
             np.array([1.0, 1.0, 1.0]),
+            "binary",
         ),
         None,
     )
@@ -247,16 +313,22 @@ def test_notes():
         [
             annotations.NoteData(
                 np.array([[0.0, 0.5, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 np.array([1108.731, 1108.731, 1108.731]),
+                "hz",
                 np.array([1.0, 1.0, 1.0]),
+                "binary",
             ),
             None,
         ],
         (
             annotations.NoteData(
                 np.array([[0.0, 0.8, 1.0], [0.5, 1.0, 1.5]]).T,
+                "s",
                 np.array([1108.731, 1108.731, 1108.731]),
+                "hz",
                 np.array([1.0, 1.0, 1.0]),
+                "binary",
             ),
             "notes_2",
         ),
@@ -266,7 +338,9 @@ def test_notes():
         (
             annotations.EventData(
                 np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                "s",
                 ["event A", "event B"],
+                "open",
             ),
             None,
         )
@@ -318,7 +392,9 @@ def test_sections():
         (
             annotations.SectionData(
                 np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                "s",
                 ["verse A", "verse B", "verse A"],
+                "open",
             ),
             None,
         )
@@ -327,7 +403,9 @@ def test_sections():
         (
             annotations.SectionData(
                 np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                "s",
                 ["verse A", "verse B", "verse A"],
+                "open",
             ),
             "sections_2",
         )
@@ -336,14 +414,18 @@ def test_sections():
         (
             annotations.SectionData(
                 np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                "s",
                 ["verse A", "verse B", "verse A"],
+                "open",
             ),
             "sections_1",
         ),
         (
             annotations.SectionData(
                 np.array([[0.0, 15.0, 20.0], [15.0, 20.0, 30.0]]).T,
+                "s",
                 ["verse A", "verse B", "verse C"],
+                "open",
             ),
             "sections_2",
         ),
@@ -351,7 +433,9 @@ def test_sections():
     section_data_4 = (
         annotations.SectionData(
             np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+            "s",
             ["verse A", "verse B", "verse A"],
+            "open",
         ),
         None,
     )
@@ -359,14 +443,18 @@ def test_sections():
         [
             annotations.SectionData(
                 np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                "s",
                 ["verse A", "verse B", "verse A"],
+                "open",
             ),
             None,
         ],
         (
             annotations.SectionData(
                 np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                "s",
                 ["verse A", "verse B", "verse A"],
+                "open",
             ),
             "sections_2",
         ),
@@ -376,7 +464,9 @@ def test_sections():
         (
             annotations.EventData(
                 np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                "s",
                 ["event A", "event B"],
+                "open",
             ),
             None,
         )
@@ -430,14 +520,18 @@ def test_multi_sections():
                 (
                     annotations.SectionData(
                         np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse A", "verse B", "verse A"],
+                        "open",
                     ),
                     None,
                 ),
                 (
                     annotations.SectionData(
                         np.array([[0.0, 15.0, 20.0], [15.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse a", "verse b", "verse a"],
+                        "open",
                     ),
                     None,
                 ),
@@ -452,14 +546,18 @@ def test_multi_sections():
                 (
                     annotations.SectionData(
                         np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse A", "verse B", "verse A"],
+                        "open",
                     ),
                     0,
                 ),
                 (
                     annotations.SectionData(
                         np.array([[0.0, 15.0, 20.0], [15.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse a", "verse b", "verse a"],
+                        "open",
                     ),
                     1,
                 ),
@@ -473,14 +571,18 @@ def test_multi_sections():
                 (
                     annotations.SectionData(
                         np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse A", "verse B", "verse A"],
+                        "open",
                     ),
                     0,
                 ),
                 (
                     annotations.SectionData(
                         np.array([[0.0, 15.0, 20.0], [15.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse a", "verse b", "verse a"],
+                        "open",
                     ),
                     1,
                 ),
@@ -492,14 +594,18 @@ def test_multi_sections():
                 (
                     annotations.SectionData(
                         np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse A", "verse B", "verse A"],
+                        "open",
                     ),
                     0,
                 ),
                 (
                     annotations.SectionData(
                         np.array([[0.0, 15.0, 20.0], [15.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse a", "verse b", "verse a"],
+                        "open",
                     ),
                     1,
                 ),
@@ -512,14 +618,18 @@ def test_multi_sections():
             (
                 annotations.SectionData(
                     np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                    "s",
                     ["verse A", "verse B", "verse A"],
+                    "open",
                 ),
                 None,
             ),
             (
                 annotations.SectionData(
                     np.array([[0.0, 15.0, 20.0], [15.0, 20.0, 25.0]]).T,
+                    "s",
                     ["verse a", "verse b", "verse a"],
+                    "open",
                 ),
                 None,
             ),
@@ -532,14 +642,18 @@ def test_multi_sections():
                 (
                     annotations.SectionData(
                         np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse A", "verse B", "verse A"],
+                        "open",
                     ),
                     None,
                 ),
                 (
                     annotations.SectionData(
                         np.array([[0.0, 15.0, 20.0], [15.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse a", "verse b", "verse a"],
+                        "open",
                     ),
                     None,
                 ),
@@ -553,14 +667,18 @@ def test_multi_sections():
                 (
                     annotations.SectionData(
                         np.array([[0.0, 10.0, 20.0], [10.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse A", "verse B", "verse A"],
+                        "open",
                     ),
                     None,
                 ),
                 (
                     annotations.SectionData(
                         np.array([[0.0, 15.0, 20.0], [15.0, 20.0, 25.0]]).T,
+                        "s",
                         ["verse a", "verse b", "verse a"],
+                        "open",
                     ),
                     None,
                 ),
@@ -575,14 +693,18 @@ def test_multi_sections():
                 (
                     annotations.EventData(
                         np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                        "s",
                         ["event A", "event B"],
+                        "open",
                     ),
                     None,
                 ),
                 (
                     annotations.EventData(
                         np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                        "s",
                         ["event A", "event B"],
+                        "open",
                     ),
                     None,
                 ),
@@ -659,26 +781,50 @@ def test_multi_sections():
 
 
 def test_keys():
-    key_data_1 = [(annotations.KeyData(np.array([[0.0], [100.0]]).T, ["A"]), None)]
-    key_data_2 = [(annotations.KeyData(np.array([[0.0], [100.0]]).T, ["A"]), "keys_1")]
+    key_data_1 = [
+        (
+            annotations.KeyData(np.array([[0.0], [100.0]]).T, "s", ["A"], "key_mode"),
+            None,
+        )
+    ]
+    key_data_2 = [
+        (
+            annotations.KeyData(np.array([[0.0], [100.0]]).T, "s", ["A"], "key_mode"),
+            "keys_1",
+        )
+    ]
     key_data_3 = [
-        (annotations.KeyData(np.array([[0.0], [100.0]]).T, ["A"]), "keys_1"),
-        (annotations.KeyData(np.array([[0.0], [50.0]]).T, ["B"]), "keys_2"),
+        (
+            annotations.KeyData(np.array([[0.0], [100.0]]).T, "s", ["A"], "key_mode"),
+            "keys_1",
+        ),
+        (
+            annotations.KeyData(np.array([[0.0], [50.0]]).T, "s", ["B"], "key_mode"),
+            "keys_2",
+        ),
     ]
     key_data_4 = (
-        annotations.KeyData(np.array([[0.0], [100.0]]).T, ["A"]),
+        annotations.KeyData(np.array([[0.0], [100.0]]).T, "s", ["A"], "key_mode"),
         "keys_1",
     )
     key_data_5 = [
-        [annotations.KeyData(np.array([[0.0], [100.0]]).T, ["A"]), "keys_1"],
-        (annotations.KeyData(np.array([[0.0], [50.0]]).T, ["B"]), "keys_2"),
+        [
+            annotations.KeyData(np.array([[0.0], [100.0]]).T, "s", ["A"], "key_mode"),
+            "keys_1",
+        ],
+        (
+            annotations.KeyData(np.array([[0.0], [50.0]]).T, "s", ["B"], "key_mode"),
+            "keys_2",
+        ),
     ]
     key_data_6 = [(None, None)]
     key_data_7 = [
         (
             annotations.EventData(
                 np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                "s",
                 ["event A", "event B"],
+                "open",
             ),
             None,
         )
@@ -729,7 +875,12 @@ def test_f0s():
     f0_data_1 = [
         (
             annotations.F0Data(
-                np.array([0.016, 0.048]), np.array([0.0, 260.9]), np.array([0.0, 1.0])
+                np.array([0.016, 0.048]),
+                "s",
+                np.array([0.0, 260.9]),
+                "hz",
+                np.array([0.0, 1.0]),
+                "binary",
             ),
             None,
         )
@@ -737,7 +888,12 @@ def test_f0s():
     f0_data_2 = [
         (
             annotations.F0Data(
-                np.array([0.016, 0.048]), np.array([0.0, 260.9]), np.array([0.0, 1.0])
+                np.array([0.016, 0.048]),
+                "s",
+                np.array([0.0, 260.9]),
+                "hz",
+                np.array([0.0, 1.0]),
+                "binary",
             ),
             "f0s_1",
         )
@@ -745,33 +901,58 @@ def test_f0s():
     f0_data_3 = [
         (
             annotations.F0Data(
-                np.array([0.016, 0.048]), np.array([0.0, 260.9]), np.array([0.0, 1.0])
+                np.array([0.016, 0.048]),
+                "s",
+                np.array([0.0, 260.9]),
+                "hz",
+                np.array([0.0, 1.0]),
+                "binary",
             ),
             "f0s_1",
         ),
         (
             annotations.F0Data(
-                np.array([0.003, 0.012]), np.array([0.0, 230.5]), np.array([0.0, 1.0])
+                np.array([0.003, 0.012]),
+                "s",
+                np.array([0.0, 230.5]),
+                "hz",
+                np.array([0.0, 1.0]),
+                "binary",
             ),
             "f0s_2",
         ),
     ]
     f0_data_4 = (
         annotations.F0Data(
-            np.array([0.016, 0.048]), np.array([0.0, 260.9]), np.array([0.0, 1.0])
+            np.array([0.016, 0.048]),
+            "s",
+            np.array([0.0, 260.9]),
+            "hz",
+            np.array([0.0, 1.0]),
+            "binary",
         ),
         "f0s_1",
     )
     f0_data_5 = [
         [
             annotations.F0Data(
-                np.array([0.016, 0.048]), np.array([0.0, 260.9]), np.array([0.0, 1.0])
+                np.array([0.016, 0.048]),
+                "s",
+                np.array([0.0, 260.9]),
+                "hz",
+                np.array([0.0, 1.0]),
+                "binary",
             ),
             "f0s_1",
         ],
         (
             annotations.F0Data(
-                np.array([0.003, 0.012]), np.array([0.0, 230.5]), np.array([0.0, 1.0])
+                np.array([0.003, 0.012]),
+                "s",
+                np.array([0.0, 230.5]),
+                "hz",
+                np.array([0.0, 1.0]),
+                "binary",
             ),
             "f0s_2",
         ),
@@ -781,7 +962,9 @@ def test_f0s():
         (
             annotations.EventData(
                 np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                "s",
                 ["event A", "event B"],
+                "open",
             ),
             None,
         )
@@ -799,7 +982,7 @@ def test_f0s():
         {"frequency": 0.0, "index": 0, "voiced": False},
         {"frequency": 260.9, "index": 0, "voiced": True},
     ]
-    assert confidence == [0.0, 1.0]
+    assert confidence == [None, None]
 
     assert jam_2.annotations[0]["sandbox"]["name"] == "f0s_1"
 
@@ -810,7 +993,7 @@ def test_f0s():
         {"frequency": 0.0, "index": 0, "voiced": False},
         {"frequency": 260.9, "index": 0, "voiced": True},
     ]
-    assert confidence == [0.0, 1.0]
+    assert confidence == [None, None]
 
     time, duration, value, confidence = get_jam_data(jam_3, "pitch_contour", 1)
     assert time == [0.003, 0.012]
@@ -819,7 +1002,7 @@ def test_f0s():
         {"frequency": 0.0, "index": 0, "voiced": False},
         {"frequency": 230.5, "index": 0, "voiced": True},
     ]
-    assert confidence == [0.0, 1.0]
+    assert confidence == [None, None]
 
     time, duration, value, confidence = get_jam_data(jam_6, "pitch_contour", 0)
     assert time == []
@@ -842,8 +1025,9 @@ def test_lyrics():
         (
             annotations.LyricData(
                 np.array([[0.027, 0.232], [0.227, 0.742]]).T,
+                "s",
                 ["The", "Test"],
-                ["", ""],
+                "words",
             ),
             None,
         )
@@ -852,8 +1036,9 @@ def test_lyrics():
         (
             annotations.LyricData(
                 np.array([[0.027, 0.232], [0.227, 0.742]]).T,
+                "s",
                 ["The", "Test"],
-                ["", ""],
+                "words",
             ),
             "lyrics_1",
         )
@@ -862,16 +1047,18 @@ def test_lyrics():
         (
             annotations.LyricData(
                 np.array([[0.027, 0.232], [0.227, 0.742]]).T,
+                "s",
                 ["The", "Test"],
-                ["", ""],
+                "words",
             ),
             "lyrics_1",
         ),
         (
             annotations.LyricData(
                 np.array([[0.0, 0.232], [0.227, 0.742]]).T,
+                "s",
                 ["is", "cool"],
-                ["", ""],
+                "words",
             ),
             "lyrics_2",
         ),
@@ -879,8 +1066,9 @@ def test_lyrics():
     lyrics_data_4 = (
         annotations.LyricData(
             np.array([[0.027, 0.232], [0.227, 0.742]]).T,
+            "s",
             ["The", "Test"],
-            ["", ""],
+            "words",
         ),
         "lyrics_1",
     )
@@ -888,16 +1076,18 @@ def test_lyrics():
         (
             annotations.LyricData(
                 np.array([[0.027, 0.232], [0.227, 0.742]]).T,
+                "s",
                 ["The", "Test"],
-                ["", ""],
+                "words",
             ),
             "lyrics_1",
         ),
         [
             annotations.LyricData(
                 np.array([[0.0, 0.232], [0.227, 0.742]]).T,
+                "s",
                 ["is", "cool"],
-                ["", ""],
+                "words",
             ),
             "lyrics_2",
         ],
@@ -907,7 +1097,9 @@ def test_lyrics():
         (
             annotations.EventData(
                 np.array([[0.2, 0.3], [0.3, 0.4]]).T,
+                "s",
                 ["event A", "event B"],
+                "open",
             ),
             None,
         )
@@ -1014,21 +1206,21 @@ def test_events():
     event_data1 = [
         (
             annotations.EventData(
-                np.array([[0.2, 0.3], [0.3, 0.4]]),
-                ["event A", "event B"],
+                np.array([[0.2, 0.3], [0.3, 0.4]]), "s", ["event A", "event B"], "open"
             ),
             "I am a description",
         )
     ]
     event_data2 = [
         (
-            annotations.EventData(np.array([[0.2, 0.3], [0.3, 0.4]]), ["2", "event B"]),
+            annotations.EventData(
+                np.array([[0.2, 0.3], [0.3, 0.4]]), "s", ["2", "event B"], "open"
+            ),
             "events 1",
         ),
         (
             annotations.EventData(
-                np.array([[0.2, 0.3], [0.3, 0.4]]),
-                ["", "a great label"],
+                np.array([[0.2, 0.3], [0.3, 0.4]]), "s", ["", "a great label"], "open"
             ),
             "events 2",
         ),
@@ -1036,8 +1228,10 @@ def test_events():
     event_data3 = [
         (
             annotations.EventData(
-                np.array([[0.2, 0.3], [0.3, 20.0]]),  # invalid because > duration
+                np.array([[0.2, 0.3], [0.3, 20.0]]),
+                "s",  # invalid because > duration
                 ["", "a great label"],
+                "open",
             ),
             "asdf",
         )
@@ -1131,3 +1325,8 @@ def test_duration():
     )
     assert jam4.file_metadata.duration == 1000
     assert jam4.validate()
+
+
+def test_mp3_remote_raises_error():
+    with pytest.raises(NotImplementedError):
+        jam = jams_utils.jams_converter(audio_path="gs://asdf/asdf.mp3")
